# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/talent_v4beta1/proto/profile_service.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.cloud.talent_v4beta1.proto import (
    common_pb2 as google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2,
)
from google.cloud.talent_v4beta1.proto import (
    filters_pb2 as google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_filters__pb2,
)
from google.cloud.talent_v4beta1.proto import (
    histogram_pb2 as google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_histogram__pb2,
)
from google.cloud.talent_v4beta1.proto import (
    profile_pb2 as google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_profile__pb2,
)
from google.longrunning import (
    operations_pb2 as google_dot_longrunning_dot_operations__pb2,
)
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/talent_v4beta1/proto/profile_service.proto",
    package="google.cloud.talent.v4beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\037com.google.cloud.talent.v4beta1B\023ProfileServiceProtoP\001ZAgoogle.golang.org/genproto/googleapis/cloud/talent/v4beta1;talent\242\002\003CTS"
    ),
    serialized_pb=_b(
        '\n7google/cloud/talent_v4beta1/proto/profile_service.proto\x12\x1bgoogle.cloud.talent.v4beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a.google/cloud/talent_v4beta1/proto/common.proto\x1a/google/cloud/talent_v4beta1/proto/filters.proto\x1a\x31google/cloud/talent_v4beta1/proto/histogram.proto\x1a/google/cloud/talent_v4beta1/proto/profile.proto\x1a#google/longrunning/operations.proto\x1a\x19google/protobuf/any.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto\x1a\x17google/rpc/status.proto"\x90\x01\n\x13ListProfilesRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x0e\n\x06\x66ilter\x18\x05 \x01(\t\x12\x12\n\npage_token\x18\x02 \x01(\t\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12-\n\tread_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMask"g\n\x14ListProfilesResponse\x12\x36\n\x08profiles\x18\x01 \x03(\x0b\x32$.google.cloud.talent.v4beta1.Profile\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t"\x86\x01\n\x14\x43reateProfileRequest\x12\x32\n\x06parent\x18\x01 \x01(\tB"\xe0\x41\x02\xfa\x41\x1c\n\x1ajobs.googleapis.com/Tenant\x12:\n\x07profile\x18\x02 \x01(\x0b\x32$.google.cloud.talent.v4beta1.ProfileB\x03\xe0\x41\x02"F\n\x11GetProfileRequest\x12\x31\n\x04name\x18\x01 \x01(\tB#\xe0\x41\x02\xfa\x41\x1d\n\x1bjobs.googleapis.com/Profile"\x83\x01\n\x14UpdateProfileRequest\x12:\n\x07profile\x18\x01 \x01(\x0b\x32$.google.cloud.talent.v4beta1.ProfileB\x03\xe0\x41\x02\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask"I\n\x14\x44\x65leteProfileRequest\x12\x31\n\x04name\x18\x01 \x01(\tB#\xe0\x41\x02\xfa\x41\x1d\n\x1bjobs.googleapis.com/Profile"\xdc\x03\n\x15SearchProfilesRequest\x12\x32\n\x06parent\x18\x01 \x01(\tB"\xe0\x41\x02\xfa\x41\x1c\n\x1ajobs.googleapis.com/Tenant\x12K\n\x10request_metadata\x18\x02 \x01(\x0b\x32,.google.cloud.talent.v4beta1.RequestMetadataB\x03\xe0\x41\x02\x12@\n\rprofile_query\x18\x03 \x01(\x0b\x32).google.cloud.talent.v4beta1.ProfileQuery\x12\x11\n\tpage_size\x18\x04 \x01(\x05\x12\x12\n\npage_token\x18\x05 \x01(\t\x12\x0e\n\x06offset\x18\x06 \x01(\x05\x12\x1b\n\x13\x64isable_spell_check\x18\x07 \x01(\x08\x12\x10\n\x08order_by\x18\x08 \x01(\t\x12\x1b\n\x13\x63\x61se_sensitive_sort\x18\t \x01(\x08\x12\x46\n\x11histogram_queries\x18\n \x03(\x0b\x32+.google.cloud.talent.v4beta1.HistogramQuery\x12\x15\n\rresult_set_id\x18\x0c \x01(\t\x12\x1e\n\x16strict_keywords_search\x18\r \x01(\x08"\x93\x03\n\x16SearchProfilesResponse\x12\x1c\n\x14\x65stimated_total_size\x18\x01 \x01(\x03\x12I\n\x10spell_correction\x18\x02 \x01(\x0b\x32/.google.cloud.talent.v4beta1.SpellingCorrection\x12?\n\x08metadata\x18\x03 \x01(\x0b\x32-.google.cloud.talent.v4beta1.ResponseMetadata\x12\x17\n\x0fnext_page_token\x18\x04 \x01(\t\x12R\n\x17histogram_query_results\x18\x05 \x03(\x0b\x32\x31.google.cloud.talent.v4beta1.HistogramQueryResult\x12K\n\x13summarized_profiles\x18\x06 \x03(\x0b\x32..google.cloud.talent.v4beta1.SummarizedProfile\x12\x15\n\rresult_set_id\x18\x07 \x01(\t"\x82\x01\n\x11SummarizedProfile\x12\x36\n\x08profiles\x18\x01 \x03(\x0b\x32$.google.cloud.talent.v4beta1.Profile\x12\x35\n\x07summary\x18\x02 \x01(\x0b\x32$.google.cloud.talent.v4beta1.Profile2\x9f\t\n\x0eProfileService\x12\xb5\x01\n\x0cListProfiles\x12\x30.google.cloud.talent.v4beta1.ListProfilesRequest\x1a\x31.google.cloud.talent.v4beta1.ListProfilesResponse"@\x82\xd3\xe4\x93\x02\x31\x12//v4beta1/{parent=projects/*/tenants/*}/profiles\xda\x41\x06parent\x12\xb5\x01\n\rCreateProfile\x12\x31.google.cloud.talent.v4beta1.CreateProfileRequest\x1a$.google.cloud.talent.v4beta1.Profile"K\x82\xd3\xe4\x93\x02\x34"//v4beta1/{parent=projects/*/tenants/*}/profiles:\x01*\xda\x41\x0eparent,profile\x12\xa2\x01\n\nGetProfile\x12..google.cloud.talent.v4beta1.GetProfileRequest\x1a$.google.cloud.talent.v4beta1.Profile">\x82\xd3\xe4\x93\x02\x31\x12//v4beta1/{name=projects/*/tenants/*/profiles/*}\xda\x41\x04name\x12\xb6\x01\n\rUpdateProfile\x12\x31.google.cloud.talent.v4beta1.UpdateProfileRequest\x1a$.google.cloud.talent.v4beta1.Profile"L\x82\xd3\xe4\x93\x02<27/v4beta1/{profile.name=projects/*/tenants/*/profiles/*}:\x01*\xda\x41\x07profile\x12\x9a\x01\n\rDeleteProfile\x12\x31.google.cloud.talent.v4beta1.DeleteProfileRequest\x1a\x16.google.protobuf.Empty">\x82\xd3\xe4\x93\x02\x31*//v4beta1/{name=projects/*/tenants/*/profiles/*}\xda\x41\x04name\x12\xb3\x01\n\x0eSearchProfiles\x12\x32.google.cloud.talent.v4beta1.SearchProfilesRequest\x1a\x33.google.cloud.talent.v4beta1.SearchProfilesResponse"8\x82\xd3\xe4\x93\x02\x32"-/v4beta1/{parent=projects/*/tenants/*}:search:\x01*\x1al\xca\x41\x13jobs.googleapis.com\xd2\x41Shttps://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/jobsB\x81\x01\n\x1f\x63om.google.cloud.talent.v4beta1B\x13ProfileServiceProtoP\x01ZAgoogle.golang.org/genproto/googleapis/cloud/talent/v4beta1;talent\xa2\x02\x03\x43TSb\x06proto3'
    ),
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_api_dot_client__pb2.DESCRIPTOR,
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
        google_dot_api_dot_resource__pb2.DESCRIPTOR,
        google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2.DESCRIPTOR,
        google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_filters__pb2.DESCRIPTOR,
        google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_histogram__pb2.DESCRIPTOR,
        google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_profile__pb2.DESCRIPTOR,
        google_dot_longrunning_dot_operations__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_any__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,
        google_dot_rpc_dot_status__pb2.DESCRIPTOR,
    ],
)


_LISTPROFILESREQUEST = _descriptor.Descriptor(
    name="ListProfilesRequest",
    full_name="google.cloud.talent.v4beta1.ListProfilesRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.talent.v4beta1.ListProfilesRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="filter",
            full_name="google.cloud.talent.v4beta1.ListProfilesRequest.filter",
            index=1,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.cloud.talent.v4beta1.ListProfilesRequest.page_token",
            index=2,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.cloud.talent.v4beta1.ListProfilesRequest.page_size",
            index=3,
            number=3,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="read_mask",
            full_name="google.cloud.talent.v4beta1.ListProfilesRequest.read_mask",
            index=4,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=553,
    serialized_end=697,
)


_LISTPROFILESRESPONSE = _descriptor.Descriptor(
    name="ListProfilesResponse",
    full_name="google.cloud.talent.v4beta1.ListProfilesResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="profiles",
            full_name="google.cloud.talent.v4beta1.ListProfilesResponse.profiles",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.cloud.talent.v4beta1.ListProfilesResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=699,
    serialized_end=802,
)


_CREATEPROFILEREQUEST = _descriptor.Descriptor(
    name="CreateProfileRequest",
    full_name="google.cloud.talent.v4beta1.CreateProfileRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.talent.v4beta1.CreateProfileRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002\372A\034\n\032jobs.googleapis.com/Tenant"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="profile",
            full_name="google.cloud.talent.v4beta1.CreateProfileRequest.profile",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=805,
    serialized_end=939,
)


_GETPROFILEREQUEST = _descriptor.Descriptor(
    name="GetProfileRequest",
    full_name="google.cloud.talent.v4beta1.GetProfileRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.talent.v4beta1.GetProfileRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b(
                "\340A\002\372A\035\n\033jobs.googleapis.com/Profile"
            ),
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=941,
    serialized_end=1011,
)


_UPDATEPROFILEREQUEST = _descriptor.Descriptor(
    name="UpdateProfileRequest",
    full_name="google.cloud.talent.v4beta1.UpdateProfileRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="profile",
            full_name="google.cloud.talent.v4beta1.UpdateProfileRequest.profile",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.cloud.talent.v4beta1.UpdateProfileRequest.update_mask",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1014,
    serialized_end=1145,
)


_DELETEPROFILEREQUEST = _descriptor.Descriptor(
    name="DeleteProfileRequest",
    full_name="google.cloud.talent.v4beta1.DeleteProfileRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.talent.v4beta1.DeleteProfileRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b(
                "\340A\002\372A\035\n\033jobs.googleapis.com/Profile"
            ),
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1147,
    serialized_end=1220,
)


_SEARCHPROFILESREQUEST = _descriptor.Descriptor(
    name="SearchProfilesRequest",
    full_name="google.cloud.talent.v4beta1.SearchProfilesRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.talent.v4beta1.SearchProfilesRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002\372A\034\n\032jobs.googleapis.com/Tenant"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="request_metadata",
            full_name="google.cloud.talent.v4beta1.SearchProfilesRequest.request_metadata",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="profile_query",
            full_name="google.cloud.talent.v4beta1.SearchProfilesRequest.profile_query",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.cloud.talent.v4beta1.SearchProfilesRequest.page_size",
            index=3,
            number=4,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.cloud.talent.v4beta1.SearchProfilesRequest.page_token",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="offset",
            full_name="google.cloud.talent.v4beta1.SearchProfilesRequest.offset",
            index=5,
            number=6,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="disable_spell_check",
            full_name="google.cloud.talent.v4beta1.SearchProfilesRequest.disable_spell_check",
            index=6,
            number=7,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="order_by",
            full_name="google.cloud.talent.v4beta1.SearchProfilesRequest.order_by",
            index=7,
            number=8,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="case_sensitive_sort",
            full_name="google.cloud.talent.v4beta1.SearchProfilesRequest.case_sensitive_sort",
            index=8,
            number=9,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="histogram_queries",
            full_name="google.cloud.talent.v4beta1.SearchProfilesRequest.histogram_queries",
            index=9,
            number=10,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="result_set_id",
            full_name="google.cloud.talent.v4beta1.SearchProfilesRequest.result_set_id",
            index=10,
            number=12,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="strict_keywords_search",
            full_name="google.cloud.talent.v4beta1.SearchProfilesRequest.strict_keywords_search",
            index=11,
            number=13,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1223,
    serialized_end=1699,
)


_SEARCHPROFILESRESPONSE = _descriptor.Descriptor(
    name="SearchProfilesResponse",
    full_name="google.cloud.talent.v4beta1.SearchProfilesResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="estimated_total_size",
            full_name="google.cloud.talent.v4beta1.SearchProfilesResponse.estimated_total_size",
            index=0,
            number=1,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="spell_correction",
            full_name="google.cloud.talent.v4beta1.SearchProfilesResponse.spell_correction",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="metadata",
            full_name="google.cloud.talent.v4beta1.SearchProfilesResponse.metadata",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.cloud.talent.v4beta1.SearchProfilesResponse.next_page_token",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="histogram_query_results",
            full_name="google.cloud.talent.v4beta1.SearchProfilesResponse.histogram_query_results",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="summarized_profiles",
            full_name="google.cloud.talent.v4beta1.SearchProfilesResponse.summarized_profiles",
            index=5,
            number=6,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="result_set_id",
            full_name="google.cloud.talent.v4beta1.SearchProfilesResponse.result_set_id",
            index=6,
            number=7,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1702,
    serialized_end=2105,
)


_SUMMARIZEDPROFILE = _descriptor.Descriptor(
    name="SummarizedProfile",
    full_name="google.cloud.talent.v4beta1.SummarizedProfile",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="profiles",
            full_name="google.cloud.talent.v4beta1.SummarizedProfile.profiles",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="summary",
            full_name="google.cloud.talent.v4beta1.SummarizedProfile.summary",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2108,
    serialized_end=2238,
)

_LISTPROFILESREQUEST.fields_by_name[
    "read_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_LISTPROFILESRESPONSE.fields_by_name[
    "profiles"
].message_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_profile__pb2._PROFILE
)
_CREATEPROFILEREQUEST.fields_by_name[
    "profile"
].message_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_profile__pb2._PROFILE
)
_UPDATEPROFILEREQUEST.fields_by_name[
    "profile"
].message_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_profile__pb2._PROFILE
)
_UPDATEPROFILEREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_SEARCHPROFILESREQUEST.fields_by_name[
    "request_metadata"
].message_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._REQUESTMETADATA
)
_SEARCHPROFILESREQUEST.fields_by_name[
    "profile_query"
].message_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_filters__pb2._PROFILEQUERY
)
_SEARCHPROFILESREQUEST.fields_by_name[
    "histogram_queries"
].message_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_histogram__pb2._HISTOGRAMQUERY
)
_SEARCHPROFILESRESPONSE.fields_by_name[
    "spell_correction"
].message_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._SPELLINGCORRECTION
)
_SEARCHPROFILESRESPONSE.fields_by_name[
    "metadata"
].message_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._RESPONSEMETADATA
)
_SEARCHPROFILESRESPONSE.fields_by_name[
    "histogram_query_results"
].message_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_histogram__pb2._HISTOGRAMQUERYRESULT
)
_SEARCHPROFILESRESPONSE.fields_by_name[
    "summarized_profiles"
].message_type = _SUMMARIZEDPROFILE
_SUMMARIZEDPROFILE.fields_by_name[
    "profiles"
].message_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_profile__pb2._PROFILE
)
_SUMMARIZEDPROFILE.fields_by_name[
    "summary"
].message_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_profile__pb2._PROFILE
)
DESCRIPTOR.message_types_by_name["ListProfilesRequest"] = _LISTPROFILESREQUEST
DESCRIPTOR.message_types_by_name["ListProfilesResponse"] = _LISTPROFILESRESPONSE
DESCRIPTOR.message_types_by_name["CreateProfileRequest"] = _CREATEPROFILEREQUEST
DESCRIPTOR.message_types_by_name["GetProfileRequest"] = _GETPROFILEREQUEST
DESCRIPTOR.message_types_by_name["UpdateProfileRequest"] = _UPDATEPROFILEREQUEST
DESCRIPTOR.message_types_by_name["DeleteProfileRequest"] = _DELETEPROFILEREQUEST
DESCRIPTOR.message_types_by_name["SearchProfilesRequest"] = _SEARCHPROFILESREQUEST
DESCRIPTOR.message_types_by_name["SearchProfilesResponse"] = _SEARCHPROFILESRESPONSE
DESCRIPTOR.message_types_by_name["SummarizedProfile"] = _SUMMARIZEDPROFILE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListProfilesRequest = _reflection.GeneratedProtocolMessageType(
    "ListProfilesRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_LISTPROFILESREQUEST,
        __module__="google.cloud.talent_v4beta1.proto.profile_service_pb2",
        __doc__="""List profiles request.
  
  
  Attributes:
      parent:
          Required. The resource name of the tenant under which the
          profile is created.  The format is
          "projects/{project\_id}/tenants/{tenant\_id}". For example,
          "projects/foo/tenants/bar".
      filter:
          The filter string specifies the profiles to be enumerated.
          Supported operator: =, AND  The field(s) eligible for
          filtering are:  -  ``externalId`` -  ``groupId``  externalId
          and groupId cannot be specified at the same time. If both
          externalId and groupId are provided, the API will return a bad
          request error.  Sample Query:  -  externalId = "externalId-1"
          -  groupId = "groupId-1"
      page_token:
          The token that specifies the current offset (that is, starting
          result).  Please set the value to [ListProfilesResponse.next\_
          page\_token][google.cloud.talent.v4beta1.ListProfilesResponse.
          next\_page\_token] to continue the list.
      page_size:
          The maximum number of profiles to be returned, at most 100.
          Default is 100 unless a positive number smaller than 100 is
          specified.
      read_mask:
          A field mask to specify the profile fields to be listed in
          response. All fields are listed if it is unset.  Valid values
          are:  -  name
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.ListProfilesRequest)
    ),
)
_sym_db.RegisterMessage(ListProfilesRequest)

ListProfilesResponse = _reflection.GeneratedProtocolMessageType(
    "ListProfilesResponse",
    (_message.Message,),
    dict(
        DESCRIPTOR=_LISTPROFILESRESPONSE,
        __module__="google.cloud.talent_v4beta1.proto.profile_service_pb2",
        __doc__="""The List profiles response object.
  
  
  Attributes:
      profiles:
          Profiles for the specific tenant.
      next_page_token:
          A token to retrieve the next page of results. This is empty if
          there are no more results.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.ListProfilesResponse)
    ),
)
_sym_db.RegisterMessage(ListProfilesResponse)

CreateProfileRequest = _reflection.GeneratedProtocolMessageType(
    "CreateProfileRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_CREATEPROFILEREQUEST,
        __module__="google.cloud.talent_v4beta1.proto.profile_service_pb2",
        __doc__="""Create profile request.
  
  
  Attributes:
      parent:
          Required. The name of the tenant this profile belongs to.  The
          format is "projects/{project\_id}/tenants/{tenant\_id}". For
          example, "projects/foo/tenants/bar".
      profile:
          Required. The profile to be created.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.CreateProfileRequest)
    ),
)
_sym_db.RegisterMessage(CreateProfileRequest)

GetProfileRequest = _reflection.GeneratedProtocolMessageType(
    "GetProfileRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_GETPROFILEREQUEST,
        __module__="google.cloud.talent_v4beta1.proto.profile_service_pb2",
        __doc__="""Get profile request.
  
  
  Attributes:
      name:
          Required. Resource name of the profile to get.  The format is 
          "projects/{project\_id}/tenants/{tenant\_id}/profiles/{profile
          \_id}". For example, "projects/foo/tenants/bar/profiles/baz".
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.GetProfileRequest)
    ),
)
_sym_db.RegisterMessage(GetProfileRequest)

UpdateProfileRequest = _reflection.GeneratedProtocolMessageType(
    "UpdateProfileRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_UPDATEPROFILEREQUEST,
        __module__="google.cloud.talent_v4beta1.proto.profile_service_pb2",
        __doc__="""Update profile request
  
  
  Attributes:
      profile:
          Required. Profile to be updated.
      update_mask:
          A field mask to specify the profile fields to update.  A full
          update is performed if it is unset.  Valid values are:  -
          external\_id -  source -  source\_types -  uri -  is\_hirable
          -  create\_time -  update\_time -  candidate\_update\_time -
          resume\_update\_time -  resume -  person\_names -  addresses -
          email\_addresses -  phone\_numbers -  personal\_uris -
          additional\_contact\_info -  employment\_records -
          education\_records -  skills -  activities -  publications -
          patents -  certifications -  recruiting\_notes -
          custom\_attributes -  group\_id -  external\_system -
          source\_note -  primary\_responsibilities -  citizenships -
          work\_authorizations -  employee\_types -  language\_code -
          qualification\_summary -  allowed\_contact\_types -
          preferred\_contact\_types -  contact\_availability -
          language\_fluencies -  work\_preference -
          industry\_experiences -  work\_environment\_experiences -
          work\_availability -  security\_clearances -  references -
          assessments -  interviews
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.UpdateProfileRequest)
    ),
)
_sym_db.RegisterMessage(UpdateProfileRequest)

DeleteProfileRequest = _reflection.GeneratedProtocolMessageType(
    "DeleteProfileRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_DELETEPROFILEREQUEST,
        __module__="google.cloud.talent_v4beta1.proto.profile_service_pb2",
        __doc__="""Delete profile request.
  
  
  Attributes:
      name:
          Required. Resource name of the profile to be deleted.  The
          format is "projects/{project\_id}/tenants/{tenant\_id}/profile
          s/{profile\_id}". For example,
          "projects/foo/tenants/bar/profiles/baz".
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.DeleteProfileRequest)
    ),
)
_sym_db.RegisterMessage(DeleteProfileRequest)

SearchProfilesRequest = _reflection.GeneratedProtocolMessageType(
    "SearchProfilesRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_SEARCHPROFILESREQUEST,
        __module__="google.cloud.talent_v4beta1.proto.profile_service_pb2",
        __doc__="""The request body of the ``SearchProfiles`` call.
  
  
  Attributes:
      parent:
          Required. The resource name of the tenant to search within.
          The format is "projects/{project\_id}/tenants/{tenant\_id}".
          For example, "projects/foo/tenants/bar".
      request_metadata:
          Required. The meta information collected about the profile
          search user. This is used to improve the search quality of the
          service. These values are provided by users, and must be
          precise and consistent.
      profile_query:
          Search query to execute. See
          [ProfileQuery][google.cloud.talent.v4beta1.ProfileQuery] for
          more details.
      page_size:
          A limit on the number of profiles returned in the search
          results. A value above the default value 10 can increase
          search response time.  The maximum value allowed is 100.
          Otherwise an error is thrown.
      page_token:
          The pageToken, similar to offset enables users of the API to
          paginate through the search results. To retrieve the first
          page of results, set the pageToken to empty. The search
          response includes a [nextPageToken][google.cloud.talent.v4beta
          1.SearchProfilesResponse.next\_page\_token] field that can be
          used to populate the pageToken field for the next page of
          results. Using pageToken instead of offset increases the
          performance of the API, especially compared to larger offset
          values.
      offset:
          An integer that specifies the current offset (that is,
          starting result) in search results. This field is only
          considered if [page\_token][google.cloud.talent.v4beta1.Search
          ProfilesRequest.page\_token] is unset.  The maximum allowed
          value is 5000. Otherwise an error is thrown.  For example, 0
          means to search from the first profile, and 10 means to search
          from the 11th profile. This can be used for pagination, for
          example pageSize = 10 and offset = 10 means to search from the
          second page.
      disable_spell_check:
          This flag controls the spell-check feature. If ``false``, the
          service attempts to correct a misspelled query.  For example,
          "enginee" is corrected to "engineer".
      order_by:
          The criteria that determines how search results are sorted.
          Defaults is "relevance desc" if no value is specified.
          Supported options are:  -  "relevance desc": By descending
          relevance, as determined by the API    algorithms. -
          "update\_date desc": Sort by    [Profile.update\_time][google.
          cloud.talent.v4beta1.Profile.update\_time]    in descending
          order (recently updated profiles first). -  "create\_date
          desc": Sort by    [Profile.create\_time][google.cloud.talent.v
          4beta1.Profile.create\_time]    in descending order (recently
          created profiles first). -  "first\_name": Sort by    [PersonN
          ame.PersonStructuredName.given\_name][google.cloud.talent.v4be
          ta1.PersonName.PersonStructuredName.given\_name]    in
          ascending order. -  "first\_name desc": Sort by    [PersonName
          .PersonStructuredName.given\_name][google.cloud.talent.v4beta1
          .PersonName.PersonStructuredName.given\_name]    in descending
          order. -  "last\_name": Sort by    [PersonName.PersonStructure
          dName.family\_name][google.cloud.talent.v4beta1.PersonName.Per
          sonStructuredName.family\_name]    in ascending order. -
          "last\_name desc": Sort by    [PersonName.PersonStructuredName
          .family\_name][google.cloud.talent.v4beta1.PersonName.PersonSt
          ructuredName.family\_name]    in ascending order.
      case_sensitive_sort:
          When sort by field is based on alphabetical order, sort values
          case sensitively (based on ASCII) when the value is set to
          true. Default value is case in-sensitive sort (false).
      histogram_queries:
          A list of expressions specifies histogram requests against
          matching profiles for [SearchProfilesRequest][google.cloud.tal
          ent.v4beta1.SearchProfilesRequest].  The expression syntax
          looks like a function definition with parameters.  Function
          syntax: function\_name(histogram\_facet[, list of buckets])
          Data types:  -  Histogram facet: facet names with format
          [a-zA-Z][a-zA-Z0-9\_]+. -  String: string like "any string
          with backslash escape for quote(")." -  Number: whole number
          and floating point number like 10, -1 and -0.01. -  List: list
          of elements with comma(,) separator surrounded by square
          brackets. For example, [1, 2, 3] and ["one", "two", "three"].
          Built-in constants:  -  MIN (minimum number similar to java
          Double.MIN\_VALUE) -  MAX (maximum number similar to java
          Double.MAX\_VALUE)  Built-in functions:  -  bucket(start,
          end[, label]) Bucket build-in function creates a bucket
          with range of [start, end). Note that the end is exclusive.
          For    example, bucket(1, MAX, "positive number") or bucket(1,
          10).  Histogram Facets:  -  admin1: Admin1 is a global
          placeholder for referring to state,    province, or the
          particular term a country uses to define the    geographic
          structure below the country level. Examples include states
          codes such as "CA", "IL", "NY", and provinces, such as "BC". -
          locality: Locality is a global placeholder for referring to
          city,    town, or the particular term a country uses to define
          the geographic    structure below the admin1 level. Examples
          include city names such as    "Mountain View" and "New York".
          -  extended\_locality: Extended locality is concatenated
          version of    admin1 and locality with comma separator. For
          example, "Mountain    View, CA" and "New York, NY". -
          postal\_code: Postal code of profile which follows locale
          code. -  country: Country code (ISO-3166-1 alpha-2 code) of
          profile, such as    US, JP, GB. -  job\_title: Normalized job
          titles specified in EmploymentHistory. -  company\_name:
          Normalized company name of profiles to match on. -
          institution: The school name. For example, "MIT", "University
          of    California, Berkeley" -  degree: Highest education
          degree in ISCED code. Each value in degree    covers a
          specific level of education, without any expansion to upper
          nor lower levels of education degree. -
          experience\_in\_months: experience in months. 0 means 0 month
          to 1    month (exclusive). -  application\_date: The
          application date specifies application start    dates. See    
          [ApplicationDateFilter][google.cloud.talent.v4beta1.Applicatio
          nDateFilter]    for more details. -
          application\_outcome\_notes: The application outcome reason
          specifies    the reasons behind the outcome of the job
          application. See    [ApplicationOutcomeNotesFilter][google.clo
          ud.talent.v4beta1.ApplicationOutcomeNotesFilter]    for more
          details. -  application\_job\_title: The application job title
          specifies the job    applied for in the application. See    [A
          pplicationJobFilter][google.cloud.talent.v4beta1.ApplicationJo
          bFilter]    for more details. -  hirable\_status: Hirable
          status specifies the profile's hirable    status. -
          string\_custom\_attribute: String custom attributes. Values
          can be    accessed via square bracket notation like
          string\_custom\_attribute["key1"]. -
          numeric\_custom\_attribute: Numeric custom attributes. Values
          can be    accessed via square bracket notation like
          numeric\_custom\_attribute["key1"].  Example expressions:  -
          count(admin1) -  count(experience\_in\_months, [bucket(0, 12,
          "1 year"), bucket(12,    36, "1-3 years"), bucket(36, MAX, "3+
          years")]) -
          count(string\_custom\_attribute["assigned\_recruiter"]) -
          count(numeric\_custom\_attribute["favorite\_number"],
          [bucket(MIN, 0,    "negative"), bucket(0, MAX, "non-
          negative")])
      result_set_id:
          An id that uniquely identifies the result set of a [SearchProf
          iles][google.cloud.talent.v4beta1.ProfileService.SearchProfile
          s] call. The id should be retrieved from the [SearchProfilesRe
          sponse][google.cloud.talent.v4beta1.SearchProfilesResponse]
          message returned from a previous invocation of [SearchProfiles
          ][google.cloud.talent.v4beta1.ProfileService.SearchProfiles].
          A result set is an ordered list of search results.  If this
          field is not set, a new result set is computed based on the [p
          rofile\_query][google.cloud.talent.v4beta1.SearchProfilesReque
          st.profile\_query]. A new [result\_set\_id][google.cloud.talen
          t.v4beta1.SearchProfilesRequest.result\_set\_id] is returned
          as a handle to access this result set.  If this field is set,
          the service will ignore the resource and [profile\_query][goog
          le.cloud.talent.v4beta1.SearchProfilesRequest.profile\_query]
          values, and simply retrieve a page of results from the
          corresponding result set. In this case, one and only one of [p
          age\_token][google.cloud.talent.v4beta1.SearchProfilesRequest.
          page\_token] or [offset][google.cloud.talent.v4beta1.SearchPro
          filesRequest.offset] must be set.  A typical use case is to
          invoke [SearchProfilesRequest][google.cloud.talent.v4beta1.Sea
          rchProfilesRequest] without this field, then use the resulting
          [result\_set\_id][google.cloud.talent.v4beta1.SearchProfilesRe
          quest.result\_set\_id] in [SearchProfilesResponse][google.clou
          d.talent.v4beta1.SearchProfilesResponse] to page through the
          results.
      strict_keywords_search:
          This flag is used to indicate whether the service will attempt
          to understand synonyms and terms related to the search query
          or treat the query "as is" when it generates a set of results.
          By default this flag is set to false, thus allowing expanded
          results to also be returned. For example a search for
          "software engineer" might also return candidates who have
          experience in jobs similar to software engineer positions. By
          setting this flag to true, the service will only attempt to
          deliver candidates has software engineer in his/her global
          fields by treating "software engineer" as a keyword.  It is
          recommended to provide a feature in the UI (such as a
          checkbox) to allow recruiters to set this flag to true if they
          intend to search for longer boolean strings.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.SearchProfilesRequest)
    ),
)
_sym_db.RegisterMessage(SearchProfilesRequest)

SearchProfilesResponse = _reflection.GeneratedProtocolMessageType(
    "SearchProfilesResponse",
    (_message.Message,),
    dict(
        DESCRIPTOR=_SEARCHPROFILESRESPONSE,
        __module__="google.cloud.talent_v4beta1.proto.profile_service_pb2",
        __doc__="""Response of SearchProfiles method.
  
  
  Attributes:
      estimated_total_size:
          An estimation of the number of profiles that match the
          specified query.  This number isn't guaranteed to be accurate.
      spell_correction:
          The spell checking result, and correction.
      metadata:
          Additional information for the API invocation, such as the
          request tracking id.
      next_page_token:
          A token to retrieve the next page of results. This is empty if
          there are no more results.
      histogram_query_results:
          The histogram results that match with specified [SearchProfile
          sRequest.histogram\_queries][google.cloud.talent.v4beta1.Searc
          hProfilesRequest.histogram\_queries].
      summarized_profiles:
          The profile entities that match the specified [SearchProfilesR
          equest][google.cloud.talent.v4beta1.SearchProfilesRequest].
      result_set_id:
          An id that uniquely identifies the result set of a [SearchProf
          iles][google.cloud.talent.v4beta1.ProfileService.SearchProfile
          s] call for consistent results.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.SearchProfilesResponse)
    ),
)
_sym_db.RegisterMessage(SearchProfilesResponse)

SummarizedProfile = _reflection.GeneratedProtocolMessageType(
    "SummarizedProfile",
    (_message.Message,),
    dict(
        DESCRIPTOR=_SUMMARIZEDPROFILE,
        __module__="google.cloud.talent_v4beta1.proto.profile_service_pb2",
        __doc__="""Profile entry with metadata inside
  [SearchProfilesResponse][google.cloud.talent.v4beta1.SearchProfilesResponse].
  
  
  Attributes:
      profiles:
          A list of profiles that are linked by [Profile.group\_id][goog
          le.cloud.talent.v4beta1.Profile.group\_id].
      summary:
          A profile summary shows the profile summary and how the
          profile matches the search query.  In profile summary, the
          profiles with the same [Profile.group\_id][google.cloud.talent
          .v4beta1.Profile.group\_id] are merged together. Among
          profiles, same education/employment records may be slightly
          different but they are merged into one with best efforts.  For
          example, in one profile the school name is "UC Berkeley" and
          the field study is "Computer Science" and in another one the
          school name is "University of California at Berkeley" and the
          field study is "CS". The API merges these two inputs into one
          and selects one value for each field. For example, the school
          name in summary is set to "University of California at
          Berkeley" and the field of study is set to "Computer Science".
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.SummarizedProfile)
    ),
)
_sym_db.RegisterMessage(SummarizedProfile)


DESCRIPTOR._options = None
_LISTPROFILESREQUEST.fields_by_name["parent"]._options = None
_CREATEPROFILEREQUEST.fields_by_name["parent"]._options = None
_CREATEPROFILEREQUEST.fields_by_name["profile"]._options = None
_GETPROFILEREQUEST.fields_by_name["name"]._options = None
_UPDATEPROFILEREQUEST.fields_by_name["profile"]._options = None
_DELETEPROFILEREQUEST.fields_by_name["name"]._options = None
_SEARCHPROFILESREQUEST.fields_by_name["parent"]._options = None
_SEARCHPROFILESREQUEST.fields_by_name["request_metadata"]._options = None

_PROFILESERVICE = _descriptor.ServiceDescriptor(
    name="ProfileService",
    full_name="google.cloud.talent.v4beta1.ProfileService",
    file=DESCRIPTOR,
    index=0,
    serialized_options=_b(
        "\312A\023jobs.googleapis.com\322AShttps://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/jobs"
    ),
    serialized_start=2241,
    serialized_end=3424,
    methods=[
        _descriptor.MethodDescriptor(
            name="ListProfiles",
            full_name="google.cloud.talent.v4beta1.ProfileService.ListProfiles",
            index=0,
            containing_service=None,
            input_type=_LISTPROFILESREQUEST,
            output_type=_LISTPROFILESRESPONSE,
            serialized_options=_b(
                "\202\323\344\223\0021\022//v4beta1/{parent=projects/*/tenants/*}/profiles\332A\006parent"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="CreateProfile",
            full_name="google.cloud.talent.v4beta1.ProfileService.CreateProfile",
            index=1,
            containing_service=None,
            input_type=_CREATEPROFILEREQUEST,
            output_type=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_profile__pb2._PROFILE,
            serialized_options=_b(
                '\202\323\344\223\0024"//v4beta1/{parent=projects/*/tenants/*}/profiles:\001*\332A\016parent,profile'
            ),
        ),
        _descriptor.MethodDescriptor(
            name="GetProfile",
            full_name="google.cloud.talent.v4beta1.ProfileService.GetProfile",
            index=2,
            containing_service=None,
            input_type=_GETPROFILEREQUEST,
            output_type=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_profile__pb2._PROFILE,
            serialized_options=_b(
                "\202\323\344\223\0021\022//v4beta1/{name=projects/*/tenants/*/profiles/*}\332A\004name"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="UpdateProfile",
            full_name="google.cloud.talent.v4beta1.ProfileService.UpdateProfile",
            index=3,
            containing_service=None,
            input_type=_UPDATEPROFILEREQUEST,
            output_type=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_profile__pb2._PROFILE,
            serialized_options=_b(
                "\202\323\344\223\002<27/v4beta1/{profile.name=projects/*/tenants/*/profiles/*}:\001*\332A\007profile"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="DeleteProfile",
            full_name="google.cloud.talent.v4beta1.ProfileService.DeleteProfile",
            index=4,
            containing_service=None,
            input_type=_DELETEPROFILEREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=_b(
                "\202\323\344\223\0021*//v4beta1/{name=projects/*/tenants/*/profiles/*}\332A\004name"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="SearchProfiles",
            full_name="google.cloud.talent.v4beta1.ProfileService.SearchProfiles",
            index=5,
            containing_service=None,
            input_type=_SEARCHPROFILESREQUEST,
            output_type=_SEARCHPROFILESRESPONSE,
            serialized_options=_b(
                '\202\323\344\223\0022"-/v4beta1/{parent=projects/*/tenants/*}:search:\001*'
            ),
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_PROFILESERVICE)

DESCRIPTOR.services_by_name["ProfileService"] = _PROFILESERVICE

# @@protoc_insertion_point(module_scope)
